@@ -85,7 +85,7 @@ IP_INFO *get_ip_by_index(unsigned long index_addr, FILE *fp) {
 		return ipinfo;
 	}
 	record_addr = get_long_addr3(addr);
-	printf("%u\n", ip[3]);
+	//printf("%u\n", ip[3]);
 	sprintf(ipinfo->start_ip, "%u.%u.%u.%u", ip[3], ip[2], ip[1], ip[0]);
 	fseek(fp, record_addr, SEEK_SET);
 	if (!fread(ip, 4, 1, fp)) {
